@@ -25,7 +25,9 @@ __all__ = (
     "ListJobsByStatusPaginatorName",
     "ListPipelinesPaginatorName",
     "ListPresetsPaginatorName",
+    "ElasticTranscoderServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -36,6 +38,7 @@ ListJobsByPipelinePaginatorName = Literal["list_jobs_by_pipeline"]
 ListJobsByStatusPaginatorName = Literal["list_jobs_by_status"]
 ListPipelinesPaginatorName = Literal["list_pipelines"]
 ListPresetsPaginatorName = Literal["list_presets"]
+ElasticTranscoderServiceName = Literal["elastictranscoder"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -67,6 +70,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -189,6 +193,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -337,6 +342,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_jobs_by_pipeline", "list_jobs_by_status", "list_pipelines", "list_presets"
 ]
